var expect  = require('chai').expect;
var sinon   = require('sinon');
var mockery = require('mockery');

var sandbox       = sinon.sandbox.create();
var stubbedMozaik = {
    logger: {
        error: sandbox.stub(),
        info:  sandbox.stub()
    }
};
var Bus, bus;


describe('Bus', function () {

    before(function () {
        mockery.enable();
    });

    beforeEach(function () {
        mockery.registerAllowables([
            'lodash',
            '../lib/Bus',
            './chalk-mock'
        ]);
        mockery.registerMock('chalk', require('./chalk-mock'));
        Bus = require('../lib/Bus');
        bus = new Bus(stubbedMozaik);
    });

    afterEach(function () {
        sandbox.verifyAndRestore();
        mockery.deregisterAll();
    });

    after(function () {
        mockery.disable();
    });


    describe('registerApi', function () {

        it('should make the API available', function () {
            bus.registerApi('test_api', function () { });
            expect(bus.listApis()).to.deep.equal(['test_api']);

            stubbedMozaik.logger.info.yields();
            expect(stubbedMozaik.logger.info.calledWith('registered API "test_api"')).to.be.true;
        });

        /*
        it('should throw if the API was already registered', function () {
            bus.registerApi('test', function () { });

            console.log(bus.apis);

            stubbedMozaik.logger.info.yields();
            expect(stubbedMozaik.logger.info.calledWith('registered API "test_api"')).to.be.true;

            /*
            try {
                bus.registerApi('test', function () { });
            } catch (e) {
                stubbedMozaik.logger.info.yields();
                expect(stubbedMozaik.logger.info.calledWith('registered API "test_api"')).to.be.true;
            }
        });
        */
    });


    describe('addClient', function () {
        it('should add a client to the current list', function () {
            bus.addClient({}, 'test_client');

            //stubbedMozaik.logger.info.yields();
            expect(stubbedMozaik.logger.info.calledWith('registered API "test_api"')).to.be.true;
        });
    });
});